@@ -1,3 +1,3 @@
-from .models import Program, ProgramScope
+from .models import Program, ProgramScope, Domain
 from .manager import BugBountyRecon
 from .errors import ApiResponseError
