@@ -1,4 +1,5 @@
 import os
+import sys
 import typer
 from pathlib import Path, PurePath
 
@@ -8,11 +9,13 @@ if (API_TOKEN := os.environ.get("BBRECON_KEY")) is None:
         with open(PurePath.joinpath(Path.home(), ".bbrecon/token")) as f:
             API_TOKEN = f.read().strip()
     except FileNotFoundError:
-        typer.secho(
-            "No BBRECON_KEY in environment, and no key configured in your home path.",
-            fg=typer.colors.YELLOW,
-        )
-
+        if "--help" not in sys.argv and "configure key" not in " ".join(sys.argv):
+            typer.secho(
+                "No BBRECON_KEY in environment, and no key configured in your home "
+                "path.\nRun `bbrecon configure key` or set BBRECON_KEY.",
+                fg=typer.colors.YELLOW,
+            )
+            sys.exit(1)
 
 if (BASE_URL := os.environ.get("BBRECON_URL")) is None:
     BASE_URL = "https://api.bugbountyrecon.com"
